<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:template match="ConfigurationReport">
    <HTML>
    <HEAD>
      <STYLE type="text/css">
        body { background-color: #EEEEEE ; }
        h2.main { background-color: cyan ; }
        h3.section { background-color: #AAAAAA ; }
        h3.block { background-color: #3333AA ; color: white ; }
        span.path { font-weight: bold ; color: black ; }
        em.correct { font-weight: bold ; color: green ; }
        em.failure { font-weight: bold ; color: blue ; }
        em.error { font-style: normal ; font-weight: bold ; color: red }
        em.fatal { font-style: normal ; font-weight: bold ; color: black ; background-color: red }
        em.footer { font-size: smaller ; text-align: right ; }
        td.assertion { font-weight: bold ; color: black ; text-align: center ; }
        td.failure { font-weight: bold ; color: blue ; text-align: center ; }
        td.error { font-style: normal ; font-weight: bold ; color: red ; text-align: center ;  }
      </STYLE>
    </HEAD>
    <BODY>
      <H2>ConfigChecker Report</H2>
      <xsl:apply-templates select="Output"/>
      <xsl:apply-templates select="Header"/>
    </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="Output">
  	<table border="2" cellpadding="5">
  	  <tr>
    		<th>Assertions</th>
    		<th>Failures</th>
    		<th>Errors</th>
    	  </tr>
  	  <tr>
  	    <td class="assertion"><xsl:value-of select="@assertions"/></td>
  	    <td class="failure"><xsl:value-of select="@failures"/></td>
  	    <td class="error"><xsl:value-of select="@errors"/></td>
  	  </tr>
  	</table>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="Section">
    <HR/>
    <H3 class="section">
      <xsl:if test="../@label">
    		<xsl:value-of select="../@label"/>:
    	</xsl:if>
      <xsl:if test="not(../@label)">      
        <xsl:if test="@label">
          <xsl:value-of select="@label"/>:
        </xsl:if>
    	</xsl:if>
    	<xsl:value-of select="@name"/>
    </H3>
			<xsl:if test=".//Error">
		    <H4 class="error">Errors</H4>
			  <OL>
			  	<xsl:for-each select=".//Error">
						<xsl:call-template name="Error"/>
			  	</xsl:for-each>
				</OL>
			</xsl:if>
			<xsl:if test=".//Failure">
		    <H4 class="error">Failures</H4>
			  <OL>
			  	<xsl:for-each select=".//Failure">
						<xsl:call-template name="Failure"/>
			  	</xsl:for-each>
				</OL>
			</xsl:if>
			<xsl:if test="not(.//Failure)">
				<xsl:if test="not(.//Error)">
					<em class="correct">All ok.</em>
				</xsl:if>
			</xsl:if>
  </xsl:template>

  <xsl:template name="Error">
    	<LI><em class="error">
        <xsl:if test="@id">
          <xsl:value-of select="@id"/>
          <xsl:text>: </xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
        </em>
      </LI>
  </xsl:template>

  <xsl:template name="Failure">
    <LI><em class="failure">
        <xsl:if test="@id">
          <xsl:value-of select="@id"/>
          <xsl:text>: </xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
      </em>
    </LI>
  </xsl:template>

  <xsl:template match="Section/Variable">
  </xsl:template>

  <xsl:template match="Variable[@name='BLOCK']">
    <h3 class="block"><xsl:value-of select="."/></h3>
  </xsl:template>

  <xsl:template match="Header">
    <HR/>
    <EM class="footer">
      Created <xsl:value-of select="ExecutionDate"/><xsl:text> </xsl:text>
      by <xsl:value-of select="Program"/><xsl:text> </xsl:text><xsl:value-of select="Version"/>
    </EM>
  </xsl:template>

</xsl:stylesheet>
