<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:template match="ConfigurationReport">
    <HTML>
      <HEAD>
        <STYLE type="text/css">
          body { background-color: #EEEEEE ; }
          h2.main { background-color: cyan ; }
          h3.section { background-color: #AAAAAA ; }
          h3.group { background-color: #4C6C8F ; color: white ; }
          span.path { font-weight: bold ; color: black ; }
          em.element { font-style: normal ; font-weight: bold ; }
          em.correct { font-weight: bold ; color: green ; }
          em.failure { font-weight: bold ; color: #FF66AA ; }
          em.error { font-style: normal ; font-weight: bold ; color: red }
          em.fatal { font-style: normal ; font-weight: bold ; color: black ; background-color: red }
          em.footer { font-size: smaller ; text-align: right ; }
          th { background-color: #A6B6C6 ; color: black ; }
          table { background-color: #CFDCED ;}
        </STYLE>
      </HEAD>
      <BODY>
        <H2><xsl:value-of select="//Variable[@name='report.title']" /></H2>
        <xsl:apply-templates select="Output" />
        <xsl:apply-templates select="Header" />
      </BODY>
    </HTML>
  </xsl:template>

  <!-- **************** Output **************** -->
  <xsl:template match="Output">
    <xsl:apply-templates select="Block" />
  </xsl:template>

  <!-- **************** Output **************** -->
  <xsl:template match="Block[@type='group']">
    <HR />
    <H3 class="group"><xsl:value-of select="@label"/></H3>
    <xsl:apply-templates />
  </xsl:template>

  <!-- **************** Manifest File List **************** -->
  <xsl:template match="Block[@type='jarManifestList']">
    <H3 class="section">JAR files manifest: <xsl:value-of select="@label" /></H3>
    <TABLE border="2" cellpadding="2" width="100%">
      <TR>
        <TH>JAR File</TH>
        <TH>Name</TH>
        <TH>Specification Title</TH>
        <TH>Specification Vendor</TH>
        <TH>Specification Version</TH>
        <TH>Implementation Title</TH>
        <TH>Implementation Vendor</TH>
        <TH>Implementation Version</TH>
      </TR>
      <xsl:apply-templates select="Block[@type='jarManifest']"/>
    </TABLE>
  </xsl:template>

  <!-- **************** Manifest File **************** -->
  <xsl:template match="Block[@type='jarManifest']">
    <xsl:variable name="fileNotFound" select="Section/Error[@msgid='SERR015']"/>    
      <xsl:if test="$fileNotFound">
        <TR>
          <TD>
            <EM class="element"><xsl:value-of select="@label" /></EM>
          </TD>
          <TD colspan="7">
            <EM class="error"><xsl:value-of select="$fileNotFound" /></EM>
          </TD>
        </TR>
      </xsl:if>
      <xsl:if test="not($fileNotFound)">
           <xsl:apply-templates select=".//Block[@type='jarManifestSection']">
             <xsl:with-param name="jarFilename" select="@label"/>
           </xsl:apply-templates>    
      </xsl:if>
      
  </xsl:template>
  
  <!-- **************** Manifest File Section **************** -->
  <xsl:template match="Block[@type='jarManifestSection']">
    <xsl:param name="jarFilename"/>
    <xsl:if test="@label='DEFAULT'">
      <TR>
      <TD>
        <EM class="element"><xsl:value-of select="$jarFilename"/></EM>
      </TD>
      <TD><xsl:text> </xsl:text></TD>
      <xsl:call-template name="manifestElements"/>
      </TR>
    </xsl:if>
    <xsl:if test="not(@label='DEFAULT')">
      <TR>
      <TD><xsl:text> </xsl:text></TD>
        <TD>
          <xsl:value-of select="@label" />
        </TD>
        <xsl:call-template name="manifestElements"/>
      </TR>
    </xsl:if>
  </xsl:template>
  
  <xsl:template name="manifestElements">
     
    <TD>
      <xsl:if test="CurrentValues[@label='Specification-Title']">
        <xsl:value-of select="CurrentValues[@label='Specification-Title']" />
      </xsl:if>
      <xsl:if test="Error[@label='Specification-Title']">
        <EM class="error">n/a</EM>
      </xsl:if>
    </TD>
    
    <TD>
      <xsl:if test="CurrentValues[@label='Specification-Vendor']">
        <xsl:value-of select="CurrentValues[@label='Specification-Vendor']" />
     </xsl:if>
      <xsl:if test="Error[@label='Specification-Vendor']">
       <EM class="error">n/a</EM>
     </xsl:if>
    </TD>

    <TD>
      <xsl:if test="CurrentValues[@label='Specification-Version']">
        <xsl:value-of select="CurrentValues[@label='Specification-Version']" />
     </xsl:if>
      <xsl:if test="Error[@label='Specification-Version']">
       <EM class="error">n/a</EM>
     </xsl:if>
    </TD>

	    <TD>
	      <xsl:if test="CurrentValues[@label='Implementation-Title']">
	        <xsl:value-of select="CurrentValues[@label='Implementation-Title']" />
	     </xsl:if>
	      <xsl:if test="Error[@label='Implementation-Title']">
	       <EM class="error">n/a</EM>
	     </xsl:if>
	    </TD>

	    <TD>
	      <xsl:if test="CurrentValues[@label='Implementation-Vendor']">
	        <xsl:value-of select="CurrentValues[@label='Implementation-Vendor']" />
	     </xsl:if>
	      <xsl:if test="Error[@label='Implementation-Vendor']">
	       <EM class="error">n/a</EM>
	     </xsl:if>
	    </TD>

	    <TD>
	      <xsl:if test="CurrentValues[@label='Implementation-Version']">
	        <xsl:value-of select="CurrentValues[@label='Implementation-Version']" />
	     </xsl:if>
	      <xsl:if test="Error[@label='Implementation-Version']">
	       <EM class="error">n/a</EM>
	     </xsl:if>
	    </TD>
  </xsl:template>

  <!-- **************** Simple Text List **************** -->
  <xsl:template match="Block[@type='simpleTextList']">
    <H3 class="section"><xsl:value-of select="@label"/></H3>
    <TABLE border="2" cellpadding="2">
      <xsl:if test="@title">
        <TR>
          <TH>
          	<xsl:value-of select="@title" />
          </TH>
        </TR>
      </xsl:if>
      <xsl:apply-templates select="Block[@type='simpleText']"/>
    </TABLE>
  </xsl:template>

  <!-- **************** Simple Text **************** -->
  <xsl:template match="Block[@type='simpleText']">
    <xsl:if test="Section/CurrentValues/Value">
      <TR>
        <TD>
          <xsl:value-of select="Section/CurrentValues/Value" />
        </TD>
      </TR>
    </xsl:if>
    <xsl:if test="Section/Error">
      <TR>
        <TD>
          <EM class="error">
          <xsl:value-of select="Section/Error"/>
          <xsl:if test="Section/@name">
            (<xsl:value-of select="Section/@name"/>)
          </xsl:if>
          </EM>
        </TD>
      </TR>
    </xsl:if>
  </xsl:template>

  <!-- **************** Key/Value Pairs **************** -->
  <xsl:template match="Block[@type='nameValuePairs']">
    <H3 class="section"><xsl:value-of select="@label"/></H3>
    <TABLE border="2" cellpadding="2">
        <TR>
          <TH>Name</TH>
          <TH>Value</TH>
        </TR>
      <xsl:apply-templates select="./CurrentValues"/>
    </TABLE>
  </xsl:template>

  <!-- **************** Current Values **************** -->
  <xsl:template match="CurrentValues">
      <TR>
        <TD>
          <xsl:if test="@label">
            <xsl:value-of select="@label" />
          </xsl:if>
          <xsl:if test="not(@label)">
            <xsl:value-of select="@element" />
          </xsl:if>
        </TD>
        <TD>
          <xsl:value-of select="Value[1]"/>
        </TD>
      </TR>
  </xsl:template>

  <!-- **************** Skip untyped blocks **************** -->
  <xsl:template match="Block">
  </xsl:template>

  <!-- **************** Skip untyped blocks **************** -->
  <xsl:template match="Section">
  	<xsl:apply-templates />
  </xsl:template>

  <!-- **************** Footer **************** -->
  <xsl:template match="Header">
    <HR />
    <EM class="footer">
      Created
      <xsl:value-of select="ExecutionDate" />
      <xsl:text></xsl:text>
      by
      <xsl:value-of select="Program" />
      <xsl:text></xsl:text>
      <xsl:value-of select="Version" />
    </EM>
  </xsl:template>

</xsl:stylesheet>
